function run_test(cvt_to_int)
    if (nargin==0)
        cvt_to_int = @(x)round(x);
    end
    
    close all

    % The SlideAC reference image.
    ref_img = imread('cmu1_slideac_lvl9.tif');
    
    % The reconstructed image - input images are coming from split-mirax.py
    rec_img = reconstruct({'cmu1_tiles1_lvl9.jpg','cmu1_tiles2_lvl9.jpg'},cvt_to_int);
    
    % Well, we are reoncstrucing too much
    rec_sub_img = rec_img(:,1:256,:);   
    
    subplot(1,3,1);
    imshow(ref_img);
    title('reference image');
    
    subplot(1,3,2);
    imshow(rec_sub_img);
    title('reconstructed image');
    
    subplot(1,3,3);
    openslide_img = imread('cmu1_openslide_lvl9.ppm');
    imshow(openslide_img);
    
    figure;
    
    % Sum of absolute differences per channel
    diff_img = uint8(abs(int16(rec_sub_img)-int16(ref_img)));    
    
    subplot(1,2,1);
    imshow(diff_img);    
    
    % This is important! We compute the SAD only on non-zero pixels.
    % That mean, only the mean error, where the intensity difference was
    % not already zero.
    mean_sad = sum(diff_img(:)) / nnz(diff_img);
    fig_title = ['matlab - slideac (mean SAD: ' num2str(mean_sad) ')'];        
    title(fig_title);
    
    % Sum of absolute differences per channel
    diff_img = uint8(abs(int16(openslide_img)-int16(ref_img)));    
    
    subplot(1,2,2);
    imshow(diff_img);    
    
    % This is important! We compute the SAD only on non-zero pixels.
    % That mean, only the mean error, where the intensity difference was
    % not already zero.
    mean_sad = sum(diff_img(:)) / nnz(diff_img);
    fig_title = ['openslide - slideac (mean SAD: ' num2str(mean_sad) ')'];
    title(fig_title);    
end
